IconRoundedProgressBar class

Inheritance

Constructors

IconRoundedProgressBar({required Widget icon, double widthIconSection = 50, double percent = 40, double height = 50, RoundedProgressBarStyle? style, RoundedProgressBarTheme? theme, EdgeInsetsGeometry? margin, bool reverse = false, Widget? childCenter, Widget? childLeft, Widget? childRight, int milliseconds = 500, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry? paddingChildLeft, EdgeInsetsGeometry? paddingChildRight})

Properties

borderRadius → BorderRadiusGeometry?
final
childCenter → Widget?
final
childLeft → Widget?
final
childRight → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
icon → Widget
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
final
milliseconds → int
final
paddingChildLeft → EdgeInsetsGeometry?
final
paddingChildRight → EdgeInsetsGeometry?
final
percent → double
final
reverse → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → RoundedProgressBarStyle?
final
theme → RoundedProgressBarTheme?
final
widthIconSection → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited